[PATCH -next 4/8] mm: damon: add temporary damon_get_folio()

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Introduce a temporary wrapper function damon_get_folio(), which
help us to convert damon related function to use folios, and it
will be droped once the conversion is completed.

Signed-off-by: Kefeng Wang <wangkefeng.wang@xxxxxxxxxx>
---
 mm/damon/ops-common.c | 18 +++++++++---------
 mm/damon/ops-common.h |  8 +++++++-
 2 files changed, 16 insertions(+), 10 deletions(-)

diff --git a/mm/damon/ops-common.h b/mm/damon/ops-common.h
index 8d82d3722204..4ee607813981 100644
--- a/mm/damon/ops-common.h
+++ b/mm/damon/ops-common.h
@@ -7,7 +7,13 @@
 
 #include <linux/damon.h>
 
-struct page *damon_get_page(unsigned long pfn);
+struct folio *damon_get_folio(unsigned long pfn);
+static inline struct page *damon_get_page(unsigned long pfn)
+{
+	struct folio *folio = damon_get_folio(pfn);
+
+	return &folio->page;
+}
 
 void damon_ptep_mkold(pte_t *pte, struct mm_struct *mm, unsigned long addr);
 void damon_pmdp_mkold(pmd_t *pmd, struct mm_struct *mm, unsigned long addr);
diff --git a/mm/damon/ops-common.c b/mm/damon/ops-common.c
index 75409601f934..40b79b022129 100644
--- a/mm/damon/ops-common.c
+++ b/mm/damon/ops-common.c
@@ -13,24 +13,24 @@
 #include "ops-common.h"
 
 /*
  * Get an online page for a pfn if it's in the LRU list.  Otherwise, returns
  * NULL.
  *
  * The body of this function is stolen from the 'page_idle_get_page()'.  We
  * steal rather than reuse it because the code is quite simple.
  */
-struct page *damon_get_page(unsigned long pfn)
+struct folio *damon_get_folio(unsigned long pfn)
 {
-	struct page *page = pfn_to_online_page(pfn);
+	struct folio *folio = pfn_to_online_folio(pfn);
 
-	if (!page || !PageLRU(page) || !get_page_unless_zero(page))
+	if (!folio || !folio_test_lru(folio) || !folio_try_get(folio))
 		return NULL;
 
-	if (unlikely(!PageLRU(page))) {
-		put_page(page);
-		page = NULL;
+	if (unlikely(!folio_test_lru(folio))) {
+		folio_put(folio);
+		folio = NULL;
 	}
-	return page;
+	return folio;
 }
 
 void damon_ptep_mkold(pte_t *pte, struct mm_struct *mm, unsigned long addr)
@@ -13,24 +13,24 @@
 
 /*
- * Get an online page for a pfn if it's in the LRU list.  Otherwise, returns
+ * Get an online folio for a pfn if it's in the LRU list.  Otherwise, returns
  * NULL.
  *
@@ -13,24 +13,24 @@
  * NULL.
  *
- * The body of this function is stolen from the 'page_idle_get_page()'.  We
+ * The body of this function is stolen from the 'folio_idle_get_folio()'.  We
  * steal rather than reuse it because the code is quite simple.
  */
-- 
2.35.3





[Index of Archives]     [Linux ARM Kernel]     [Linux ARM]     [Linux Omap]     [Fedora ARM]     [IETF Annouce]     [Bugtraq]     [Linux OMAP]     [Linux MIPS]     [eCos]     [Asterisk Internet PBX]     [Linux API]

  Powered by Linux